#
# spec file for package python-renderspec
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global oldpython python
Name:           python-renderspec
Version:        2.2.0
Release:        3.2
Summary:        Generate spec files from Jinja2 templates
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/renderspec
Source0:        https://files.pythonhosted.org/packages/source/r/renderspec/renderspec-%{version}.tar.gz
Patch1:         0001-Allow-selecting-suse_39-template.patch
BuildRequires:  openstack-macros
BuildRequires:  python3-Jinja2 >= 2.10
BuildRequires:  python3-ddt
BuildRequires:  python3-packaging >= 16.5
BuildRequires:  python3-pbr
BuildRequires:  python3-pymod2pkg >= 0.7.0
BuildRequires:  python3-stestr
BuildArch:      noarch

%description
renderspec is a tool to convert a .spec.j2 Jinja2 template to
a rpm .spec file which is usable for different distributions
and follow their policies and processes.

%package -n python3-renderspec
Summary:        Generate spec files from Jinja2 templates
Requires:       python3-Jinja2 >= 2.10
Requires:       python3-PyYAML >= 3.10
Requires:       python3-packaging >= 16.5
Requires:       python3-pymod2pkg >= 0.7.0
Conflicts:      %{oldpython}-renderspec < %{version}

%description -n python3-renderspec
renderspec is a tool to convert a .spec.j2 Jinja2 template to
a rpm .spec file which is usable for different distributions
and follow their policies and processes.

%package -n python-renderspec-doc
Summary:        Documentation for the renderspec utility
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme
Requires:       python3-renderspec = %{version}

%description -n python-renderspec-doc
Documentation for the renderspec tool which is a tool to convert
a spec.j2 Jinja2 template into a rpm .spec file.

%prep
%autosetup -p 1 -n renderspec-2.2.0
%py_req_cleanup

%build
%{py3_build}

PBR_VERSION=2.2.0 %sphinx_build -b html doc/source doc/build/html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}

%check
%{openstack_stestr_run}

%files -n python3-renderspec
%license LICENSE
%doc README.rst ChangeLog
%{_bindir}/renderspec
%{python3_sitelib}/renderspec
%{python3_sitelib}/*.egg-info

%files -n python-renderspec-doc
%doc doc/build/html
%license LICENSE

%changelog
* Fri Mar  3 2023 cloud-devel@suse.de
- added 0001-Allow-selecting-suse_39-template.patch
* Thu Dec  1 2022 Dirk Müller <dmueller@suse.com>
- remove unused dependencies
* Fri May 13 2022 cloud-devel@suse.de
- update to version 2.2.0
  - Correct a typo in the document
  - [community goal] Update contributor documentation
  - Use py3 as the default runtime for tox
  - drop mock from lower-constraints and requirements
  - Add support for Jinja2 3.x filters
  - Switch to OFTC
* Tue Nov 17 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v2.1.0
  * Improve distro detection for recent Fedora releases
  * Switch to newer openstackdocstheme version
  * Cleanup py27 support
  * Declare support for Python 3.8
* Tue May 12 2020 Dirk Mueller <dmueller@suse.com>
- update urls to opendev
* Tue Mar 17 2020 cloud-devel@suse.de
- update to version 2.0.0
  - Set ignore_basepython_conflict in tox
  - Add Python 3 Train unit tests
  - Drop py27 support
  - Fix urllib.urlopen for python3
  - Drop use of unittest2
  - Remove usage of platform.linux_distribution
* Fri Sep 20 2019 Dirk Mueller <dmueller@suse.com>
- add conflict for the impossible to workaround staging failures
* Thu Jul 11 2019 cloud-devel@suse.de
- update to version 1.12.0
  - Add contextfunctions 'py2' and 'py3'
* Wed Jun 26 2019 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only package
* Mon Jun 17 2019 cloud-devel@suse.de
- update to version 1.11.1
  - Switch to TOX_CONSTRAINTS_FILE
  - Update flake8 version to latest release
  - Switch to openstackdocstheme
  - OpenDev Migration Patch
  - Preserve list order in _pymod2pkg_translate
  - Fix _pymod2pkg_translate when skip_pyversion is None
  - Follow opendev rebranding
* Thu Apr 25 2019 cloud-devel@suse.de
- update to version 1.10.0
  - fix tox python3 overrides
  - Update home-page
  - Update links in README
  - Switch to stestr
  - Change openstack-dev to openstack-discuss
  - Move linter dependencies out of test-requirements
  - Removed older version of python added 3.5
  - Avoid tox_install.sh for constraints support
  - switch documentation job to new PTI
  - Update to a somewhat recent flake8 version
  - add python 3.6 unit test job
  - Updated from global requirements
  - import zuul job settings from project-config
- convert to singlespec
* Wed Apr 10 2019 Dirk Mueller <dmueller@suse.com>
- refresh spec file from master
* Wed Oct 11 2017 cloud-devel@suse.de
- update to version 1.9.1
  - Remove python_module definition from suse template
* Mon Oct  9 2017 cloud-devel@suse.de
- update to version 1.9.0
  - Add option to skip certain python version
* Mon Oct  9 2017 cloud-devel@suse.de
- update to version 1.8.0
  - Fix SUSE detection on Tumbleweed and SLE15
* Fri Sep 15 2017 cloud-devel@suse.de
- update to version 1.7.0
  - Support different py versions in py2name() and py2pkg()
  - Clarify variable name
  - Add context function `url_pypi`
  - Introduce a new --input-template-format switch
  - Semantically determine lowest version number, not lexigraphically
  - Move context related functions to extra file
  - Fix rc version handling on SUSE
  - Updated from global requirements
* Tue May 30 2017 cloud-devel@suse.de
- update to version 1.6.1
  - Sort found archives by mtime for version detection
  - Updated from global requirements
* Fri Apr 21 2017 cloud-devel@suse.de
- update to version 1.6.0
  - Return the full path when searching for archive files
  - Add 'basename' filter
* Thu Apr 13 2017 cloud-devel@suse.de
- update to version 1.5.0:
  - Look in 'output_dir' when searching archives
  - Enable and fix more tests
  - Updated from global requirements
  - Make output dir available in the context
  - Add new function fetch_source() to download files
* Wed Apr  5 2017 cloud-devel@suse.de
- update to version 1.4.0:
  - Fix docs for child templates
  - Introduce context variable 'pypi_name'
  - Updated from global requirements
  - Add dynamic version detection from archive files
* Fri Feb 10 2017 tbechtold@suse.com
- Initial packaging (version 1.3.0)
